@@ -1,8 +1,9 @@
-#!/usr/bin/env python
+#!/usr/bin/python2.7
 
 import os
 import sys
 import apt
+import commands
 
 #def checkDependencies(changes, cache):
 #    foundSomething = False
@@ -27,7 +28,7 @@ import apt
 
 try:
     cache = apt.Cache()
-    
+
     if os.getuid() == 0 :
         use_synaptic = False
         if (len(sys.argv) > 1):
@@ -42,7 +43,7 @@ try:
             #cmd.append("\"" + _("Please wait, this can take some time") + "\"")
             comnd = Popen(' '.join(cmd), shell=True)
             returnCode = comnd.wait()
-            #sts = os.waitpid(comnd.pid, 0)            
+            #sts = os.waitpid(comnd.pid, 0)
         else:
             cache.update()
 
@@ -56,12 +57,12 @@ try:
             dist_upgrade = False
     except:
         dist_upgrade = True
-        
+
     # Reopen the cache to reflect any updates
     cache.open(None)
     cache.upgrade(dist_upgrade)
     changes = cache.get_changes()
-    
+
     # Add dependencies
     #changes = checkDependencies(changes, cache)
 
@@ -72,14 +73,39 @@ try:
             oldVersion = pkg.installed.version
             size = pkg.candidate.size
             sourcePackage = pkg.candidate.source_name
+            short_description = pkg.candidate.raw_description
             description = pkg.candidate.description
             if (newVersion != oldVersion):
-                resultString = u"UPDATE###%s###%s###%s###%s###%s###%s" % (package, newVersion, oldVersion, size, sourcePackage, description)
-                print resultString.encode('ascii', 'xmlcharrefreplace');
-    
+                update_type = "package"
+                update_origin = "linuxmint"
+                for origin in pkg.candidate.origins:
+                    if origin.origin == "Ubuntu":
+                        update_origin = "ubuntu"
+                    elif origin.origin == "Debian":
+                        update_origin = "debian"
+                    if origin.origin == "Ubuntu" and '-security' in origin.archive:
+                        update_type = "security"
+                        break
+                    if origin.origin == "Debian" and '-Security' in origin.label:
+                        update_type = "security"
+                        break
+                    if origin.origin == "linuxmint":
+                        if origin.component == "romeo":
+                            update_type = "unstable"
+                            break
+                        elif origin.component == "backport":
+                            update_type = "backport"
+                            break
+                        elif pkg.name == "linux-kernel-generic":
+                            update_type = "security"
+                            break
+                        else:
+                            update_type = "linuxmint"
+
+                resultString = u"UPDATE###%s###%s###%s###%s###%s###%s###%s###%s###%s---EOL---" % (package, newVersion, oldVersion, size, sourcePackage, update_type, update_origin, short_description, description)
+                print resultString.encode('ascii', 'xmlcharrefreplace')
+
 except Exception, detail:
-    print "ERROR###ERROR###ERROR###ERROR###ERROR###ERROR###ERROR"
+    print "CHECK_APT_ERROR---EOL---"
     print detail
     sys.exit(1)
-
-
